import React, { useRef, useState } from 'react';
import { connect } from 'umi';
import ProTable from '@ant-design/pro-table';
import { PlusOutlined } from '@ant-design/icons';
import { Button, Popconfirm, Modal, Space, notification } from 'antd';
import request, { queryTable } from '@/utils/request';
import SpecialtyModel from './components/SpecialtyModel';

const Specialty = (props) => {
  console.log(props, 'props');
  const [, setLoading] = useState(false);
  const [visible, setVisible] = useState(false);

  const ref = useRef();

  const actions = [
    <Button key="button" icon={<PlusOutlined />} type="primary" onClick={() => setVisible(true)}>
      新建
    </Button>,
  ];

  const handleSubmit = (values) => {
    return request('/specialty', {
      method: 'post',
      data: { schoolId: props.data.schoolId, name: values.name },
    })
      .then(() => {
        notification.info({ message: '添加成功' });
        setVisible(false);
        // setLoading(false);
      })
      .catch((e) => {
        notification.error({ message: e.message });
        setLoading(false);
        return Promise.reject(e.message);
      });
  };
  //     setLoading(true);
  //     return request(`/school/${id}`, { method: 'put', data: { schoolId: id, ...values } })
  //       .then(() => {
  //         notification.info({ message: '修改成功' });
  //         setLoading(false);
  //         history.go('-1');
  //       })
  //       .catch((e) => {
  //         notification.error({ message: e.message });
  //         setLoading(false);
  //         return Promise.reject(e.message);
  //       });
  //   };

  const deleteSchoolClick = () => {
      console.log(ref)
    ref.current.reload();
    //   request(`/specialty/${id}`, { method: 'delete' })
    //     .then(() => {
    //       notification.success({ message: '删除成功' });
    //       ref.current.submit();
    //     })
    //     .catch((e) => {

    //       notification.error({ message: e.message });
    //     });
  };

  const columns = [
    {
      title: '专业名称',
      dataIndex: 'name',
      align: 'center',
      hideInSearch: true,
      // render: (text) => <Image src={text} />,
    },
    {
      title: '所属学校',
      dataIndex: 'schoolNmae',
      align: 'center',
      hideInSearch: true,
    },

    {
      title: '创建时间',
      dataIndex: 'createDate',
      align: 'center',
      hideInSearch: true,
      valueType: 'date',
    },
    {
      title: '操作',
      dataIndex: 'action',
      align: 'center',
      hideInSearch: true,
      render: (text, record) => (
        <Space size="middle">
          {/* <a onClick={() => handleSchoolClick(record.schoolId)}>编辑</a> */}
          <Popconfirm
            key="popconfirm"
            title={`确认删除吗?`}
            onConfirm={() => deleteSchoolClick(record.specialtyId)}
            okText="是"
            cancelText="否"
          >
            <a>删除</a>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  return (
    <>
      <ProTable
        columns={columns}
        request={(params)=>queryTable('/specialty')({...params,school:props.data.schoolId})}
        actionRef={ref}
        search={false}
        rowKey="specialtyId"
        headerTitle={props.data.name}

        toolBarRender={() => actions}
      />
      <Modal title="添加专业" visible={visible} footer={null}>
        <SpecialtyModel data={props.data} handleSubmit={(value) => handleSubmit(value)} />
      </Modal>
    </>
  );
};

export default connect((s) => ({
  typeList: s.post.typeList,
}))(Specialty);
