import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import request from '@/utils/request';
import { notification, Tabs } from 'antd';
import SchoolFrom from './components/SchoolFrom';
import Specialty from './Specialty';

const { TabPane } = Tabs;
const SchoolEdit = (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [data, setData] = useState({});
  //   const [bannerData, setBannerData] = useState({});

  useEffect(() => {
    if (id) {
      setLoading(true);
      request(`/school/${id}`)
        .then((res) => {
          setData(res);
          setLoading(false);
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    }
  }, [id]);

  const handleSubmit = (values) => {
    if (!id) {
      setLoading(true);
      return request('/school', { method: 'post', data: values })
        .then(() => {
          // props.onChange(res)
          // form.setFieldsValue(res)
          notification.info({ message: '添加成功' });
          setLoading(false);
          history.go('-1');
        })
        .catch((e) => {
          notification.error({ message: e.message });
          setLoading(false);
          return Promise.reject(e.message);
        });
    }
    setLoading(true);
    return request(`/school/${id}`, { method: 'put', data: { schoolId: id, ...values } })
      .then(() => {
        notification.info({ message: '修改成功' });
        setLoading(false);
        history.go('-1');
      })
      .catch((e) => {
        notification.error({ message: e.message });
        setLoading(false);
        return Promise.reject(e.message);
      });
  };

  return (
    <PageContainer>
      <Container>
        <Tabs>
          <TabPane tab="学校" key="1">
            <Container loading={loading}>
              <SchoolFrom data={data} handleSubmit={handleSubmit}></SchoolFrom>
            </Container>
          </TabPane>
          {id && (
            <TabPane tab="专业" key="2">
              <Specialty data={data}></Specialty>
            </TabPane>
          )}
        </Tabs>
      </Container>
    </PageContainer>
    // <PageContainer>
    //   <Container loading={loading}>
    //     <ProForm form={form} onFinish={handleSubmit}>
    //       <Form.Item
    //         name="logo"
    //         label="logo"
    //         placeholder="请选择logo"
    //         extra="支持jpg/png文件，且不超过500kb"
    //         rules={[{ required: true, message: '请上传logo' }]}
    //       >
    //         <UploadImage />
    //       </Form.Item>

    //       <ProFormText
    //         label="名称"
    //         placeholder="输入名称"
    //         name="name"
    //         rules={[{ required: true, message: '请填写名称' }]}
    //       />

    //       <ProFormTextArea
    //         label="简介"
    //         placeholder="输入简介"
    //         name="desc"
    //         rules={[{ required: true, message: '请填写简介' }]}
    //       />
    //     </ProForm>
    //   </Container>
    // </PageContainer>
  );
};

export default connect(() => ({}))(SchoolEdit);
