import React, { useEffect, useState } from 'react';
import { connect, history } from 'umi';
import { PageContainer } from '@ant-design/pro-layout';
import Container from '@/components/Container';
import request from '@/utils/request';
import { notification, Card, Descriptions, Divider, Image, Button } from 'antd';

const BannerEdit = (props) => {
  const { id } = props.location.query;
  const [loading, setLoading] = useState(false);
  const [data, setData] = useState({});

  useEffect(() => {
    if (id) {
      setLoading(true);
      request(`/person/${id}`)
        .then((res) => {
          setData(res);
          setLoading(false);
        })
        .catch((e) => {
          setLoading(false);
          notification.error({ message: e.message });
        });
    }
  }, [id]);

  return (
    <PageContainer>
      <Container loading={loading}>
        <div style={{ textAlign: 'right' }}>
          {' '}
          <Button onClick={() => history.go('-1')}>返回</Button>
        </div>

        <Card bordered={false}>
          {/* <div style={{ display: 'flex' }}>
            <div>
              <Image src={data.avatar} width={200}></Image>
            </div> */}

            <Descriptions title="学生信息" style={{ marginBottom: 32 }}>
              <Descriptions.Item label="姓名">{data.name}</Descriptions.Item>
              <Descriptions.Item label="性别">{data.sex}</Descriptions.Item>
              <Descriptions.Item label="积分">{data.createDate}</Descriptions.Item>
              <Descriptions.Item label="微信昵称">{data.nickName}</Descriptions.Item>
              <Descriptions.Item label="联系方式">{data.phone}</Descriptions.Item>
              <Descriptions.Item label="邮箱">{data.eMail}</Descriptions.Item>
            </Descriptions>
          {/* </div> */}

          <Divider style={{ marginBottom: 32 }} />
          <Descriptions title="学校信息" style={{ marginBottom: 32 }}>
            <Descriptions.Item label="学校">{data.schoolName}</Descriptions.Item>
            <Descriptions.Item label="专业">{data.specialtyName}</Descriptions.Item>
            <Descriptions.Item label="学界">{data.schoolBatch}</Descriptions.Item>
            <Descriptions.Item label="学号">{data.studentId}</Descriptions.Item>
          </Descriptions>
        </Card>
      </Container>
    </PageContainer>
  );
};

export default connect(() => ({}))(BannerEdit);
