import React, { useRef, useState } from 'react'
import { PageContainer } from '@ant-design/pro-layout';
import ProTable from '@ant-design/pro-table';
import { Modal, Input, notification } from 'antd';
import request, { queryTable } from '@/utils/request';

export default () => {
  const tableRef = useRef()
  const [current, setCurrent] = useState()
  const [inputVal, setInputVal] = useState([])
  const [show, setShow] = useState(false)

  const handleEdit = (config) => {
    setCurrent(config)
    setInputVal(config.value)
    setShow(true)
  }

  const columns = [
    {
      title: '编码',
      key: 'code',
      dataIndex: 'code',
    },
    {
      title: '描述',
      key: 'description',
      dataIndex: 'description',
    },
    {
      title: '参数值',
      key: 'value',
      dataIndex: 'value',
    },
    {
      title: '操作',
      key: 'option',
      valueType: 'option',
      width: 240,
      render: (_, role) => [
        <a key="edit" onClick={() => handleEdit(role)}>修改</a>,
      ]
    },
  ]

  const handleSubmit = () => {
    setShow(false)
    request(`/sys-config/${current.serialNo}`, { method: 'put', data: { ...current, value: inputVal } }).then(() => {
      tableRef.current.reload()
      notification.success({ message: '修改成功' })
    }).catch((e) => {
      notification.error({ message: e.message })
    })
  }
  
  return (
    <PageContainer>
      <ProTable
        actionRef={tableRef}
        columns={columns}
        request={queryTable('/sys-config')}
        rowKey="code"
        headerTitle="参数列表"
        search={false}
      />
      <Modal title="修改参数值" visible={show} onOk={handleSubmit} onCancel={() => setShow(false)} >
        <Input size="large" value={inputVal} onChange={(e) => setInputVal(e.target.value)} />
      </Modal>
    </PageContainer>
  )
}
